---
title: <span class="badge object-type-scalar"></span> InchesOfMercury
---
# <span class="badge object-type-scalar"></span> InchesOfMercury

Pressure: Inches of mercury

## Definition

```python
# Pressure: Inches of mercury
InchesOfMercury: typing.Literal["pressurehg"] = "pressurehg"
```
